==> jwinner-base-0.1.7-sources.jar: itez/plat/main/model/base/BaseTask.java <==
package itez.plat.main.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseTask<M extends BaseTask<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setCron(java.lang.String cron) {
		set("cron", cron);
		return (M)this;
	}
	
	public java.lang.String getCron() {
		return getStr("cron");
	}

	public M setTaskClass(java.lang.String taskClass) {
		set("taskClass", taskClass);
		return (M)this;
	}
	
	public java.lang.String getTaskClass() {
		return getStr("taskClass");
	}

	public M setDaemon(java.lang.Integer daemon) {
		set("daemon", daemon);
		return (M)this;
	}
	
	public java.lang.Integer getDaemon() {
		return getInt("daemon");
	}

	public M setEnable(java.lang.Integer enable) {
		set("enable", enable);
		return (M)this;
	}
	
	public java.lang.Integer getEnable() {
		return getInt("enable");
	}

	public M setRunCount(java.lang.Integer runCount) {
		set("runCount", runCount);
		return (M)this;
	}
	
	public java.lang.Integer getRunCount() {
		return getInt("runCount");
	}

	public M setRunCountOk(java.lang.Integer runCountOk) {
		set("runCountOk", runCountOk);
		return (M)this;
	}
	
	public java.lang.Integer getRunCountOk() {
		return getInt("runCountOk");
	}

	public M setRunCountFail(java.lang.Integer runCountFail) {
		set("runCountFail", runCountFail);
		return (M)this;
	}
	
	public java.lang.Integer getRunCountFail() {
		return getInt("runCountFail");
	}

	public M setRunFirstDate(java.util.Date runFirstDate) {
		set("runFirstDate", runFirstDate);
		return (M)this;
	}
	
	public java.util.Date getRunFirstDate() {
		return get("runFirstDate");
	}

	public M setRunFirstStatus(java.lang.Integer runFirstStatus) {
		set("runFirstStatus", runFirstStatus);
		return (M)this;
	}
	
	public java.lang.Integer getRunFirstStatus() {
		return getInt("runFirstStatus");
	}

	public M setRunFirstError(java.lang.String runFirstError) {
		set("runFirstError", runFirstError);
		return (M)this;
	}
	
	public java.lang.String getRunFirstError() {
		return getStr("runFirstError");
	}

	public M setRunLastDate(java.util.Date runLastDate) {
		set("runLastDate", runLastDate);
		return (M)this;
	}
	
	public java.util.Date getRunLastDate() {
		return get("runLastDate");
	}

	public M setRunLastStatus(java.lang.Integer runLastStatus) {
		set("runLastStatus", runLastStatus);
		return (M)this;
	}
	
	public java.lang.Integer getRunLastStatus() {
		return getInt("runLastStatus");
	}

	public M setRunLastError(java.lang.String runLastError) {
		set("runLastError", runLastError);
		return (M)this;
	}
	
	public java.lang.String getRunLastError() {
		return getStr("runLastError");
	}

	public M setRunNextDate(java.util.Date runNextDate) {
		set("runNextDate", runNextDate);
		return (M)this;
	}
	
	public java.util.Date getRunNextDate() {
		return get("runNextDate");
	}

}

==> jwinner-base-0.1.9-sources.jar: itez/plat/main/model/base/BaseTask.java <==
package itez.plat.main.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseTask<M extends BaseTask<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setCron(java.lang.String cron) {
		set("cron", cron);
		return (M)this;
	}
	
	public java.lang.String getCron() {
		return getStr("cron");
	}

	public M setTaskClass(java.lang.String taskClass) {
		set("taskClass", taskClass);
		return (M)this;
	}
	
	public java.lang.String getTaskClass() {
		return getStr("taskClass");
	}

	public M setTaskParams(java.lang.String taskParams) {
		set("taskParams", taskParams);
		return (M)this;
	}
	
	public java.lang.String getTaskParams() {
		return getStr("taskParams");
	}

	public M setDaemon(java.lang.Integer daemon) {
		set("daemon", daemon);
		return (M)this;
	}
	
	public java.lang.Integer getDaemon() {
		return getInt("daemon");
	}

	public M setEnable(java.lang.Integer enable) {
		set("enable", enable);
		return (M)this;
	}
	
	public java.lang.Integer getEnable() {
		return getInt("enable");
	}

	public M setRunCount(java.lang.Integer runCount) {
		set("runCount", runCount);
		return (M)this;
	}
	
	public java.lang.Integer getRunCount() {
		return getInt("runCount");
	}

	public M setRunCountOk(java.lang.Integer runCountOk) {
		set("runCountOk", runCountOk);
		return (M)this;
	}
	
	public java.lang.Integer getRunCountOk() {
		return getInt("runCountOk");
	}

	public M setRunCountFail(java.lang.Integer runCountFail) {
		set("runCountFail", runCountFail);
		return (M)this;
	}
	
	public java.lang.Integer getRunCountFail() {
		return getInt("runCountFail");
	}

	public M setRunFirstDate(java.util.Date runFirstDate) {
		set("runFirstDate", runFirstDate);
		return (M)this;
	}
	
	public java.util.Date getRunFirstDate() {
		return get("runFirstDate");
	}

	public M setRunFirstStatus(java.lang.Integer runFirstStatus) {
		set("runFirstStatus", runFirstStatus);
		return (M)this;
	}
	
	public java.lang.Integer getRunFirstStatus() {
		return getInt("runFirstStatus");
	}

	public M setRunFirstError(java.lang.String runFirstError) {
		set("runFirstError", runFirstError);
		return (M)this;
	}
	
	public java.lang.String getRunFirstError() {
		return getStr("runFirstError");
	}

	public M setRunLastDate(java.util.Date runLastDate) {
		set("runLastDate", runLastDate);
		return (M)this;
	}
	
	public java.util.Date getRunLastDate() {
		return get("runLastDate");
	}

	public M setRunLastStatus(java.lang.Integer runLastStatus) {
		set("runLastStatus", runLastStatus);
		return (M)this;
	}
	
	public java.lang.Integer getRunLastStatus() {
		return getInt("runLastStatus");
	}

	public M setRunLastError(java.lang.String runLastError) {
		set("runLastError", runLastError);
		return (M)this;
	}
	
	public java.lang.String getRunLastError() {
		return getStr("runLastError");
	}

	public M setRunNextDate(java.util.Date runNextDate) {
		set("runNextDate", runNextDate);
		return (M)this;
	}
	
	public java.util.Date getRunNextDate() {
		return get("runNextDate");
	}

}
